//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

//P1[3]:LCD Back Light
//P1[7]:LCD Contrust

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules

#define	cursor(y,x)	{LCD_1_Position(y,x);lcd_xpos=x;lcd_ypos=y;}
#define CLK 12800000.0
#define gamma 23.4871969
#define maxcnt 7200
#define mincnt 5500

extern void printf(const unsigned char *string, ...);

unsigned char lcd_xpos = 0;
unsigned char lcd_ypos = 0;

void print_chr(unsigned char c)
{
	LCD_1_Position(lcd_ypos, lcd_xpos);
	if (c == '\r') {
		lcd_xpos = 0;
		return;
	}
	if (c == '\n') {
		lcd_ypos++;
		lcd_xpos = 0;
	} else {
		LCD_1_WriteData(c);
		lcd_xpos++;
	}
}

#pragma interrupt_handler Timer16_1_ISR
#pragma interrupt_handler PWMDB16_1_ISR

int Count=0;
WORD CV, CVold, diff;
long total=0;
float freq, MF;

void Timer16_1_ISR(){
	CVold = CV;
    CV = Timer16_1_wReadCompareValue();
	diff = CVold - CV;
	if( (diff<=maxcnt) && (diff>=mincnt)){
		total += diff;
		Count ++;
	}
}

void PWMDB16_1_ISR(){
	freq = CLK / total * Count;
	MF = freq * gamma;
	cursor(0,0);
	printf("Freq:%5d.%03dHz", (int)freq, (long)(freq*1000)%1000);
	cursor(1,0);
	printf(" MF :%5d.%03dnT", (int)MF, (long)(MF*1000)%1000);
	total = 0;
	Count = 0;
}

void main()
{
    // Insert your main routine code here.
    M8C_EnableGInt;
    LCD_1_Start();
	PWM8_1_Start();
    PWM8_2_Start();	//LCD Contrast
	PWMDB16_1_Start();
	PWMDB16_1_EnableInt();
	PGA_1_Start(PGA_1_HIGHPOWER);
    PGA_2_Start(PGA_2_HIGHPOWER);
    BPF2_1_Start(BPF2_1_HIGHPOWER);
    BPF2_2_Start(BPF2_2_HIGHPOWER);
    RefMux_1_Start(RefMux_1_HIGHPOWER);
    CMPPRG_1_Start(CMPPRG_1_HIGHPOWER);
	ACB01CR2 &= ~0x40; //disable Latch
	CMP_CR1 |= 0x20; //disable Latch
    Timer16_1_Start();
    Timer16_1_EnableInt();
	DigBuf_1_Start();
}
